==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/msk_serverless_cluster/MskServerlessClusterClientAuthenticationSasl.java <==
package com.hashicorp.cdktf.providers.aws.msk_serverless_cluster;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:54.811Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.mskServerlessCluster.MskServerlessClusterClientAuthenticationSasl")
@software.amazon.jsii.Jsii.Proxy(MskServerlessClusterClientAuthenticationSasl.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MskServerlessClusterClientAuthenticationSasl extends software.amazon.jsii.JsiiSerializable {

    /**
     * iam block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/msk_serverless_cluster#iam MskServerlessCluster#iam}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.msk_serverless_cluster.MskServerlessClusterClientAuthenticationSaslIam getIam();

    /**
     * @return a {@link Builder} of {@link MskServerlessClusterClientAuthenticationSasl}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MskServerlessClusterClientAuthenticationSasl}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MskServerlessClusterClientAuthenticationSasl> {
        com.hashicorp.cdktf.providers.aws.msk_serverless_cluster.MskServerlessClusterClientAuthenticationSaslIam iam;

        /**
         * Sets the value of {@link MskServerlessClusterClientAuthenticationSasl#getIam}
         * @param iam iam block. This parameter is required.
         *            Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/msk_serverless_cluster#iam MskServerlessCluster#iam}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder iam(com.hashicorp.cdktf.providers.aws.msk_serverless_cluster.MskServerlessClusterClientAuthenticationSaslIam iam) {
            this.iam = iam;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MskServerlessClusterClientAuthenticationSasl}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MskServerlessClusterClientAuthenticationSasl build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MskServerlessClusterClientAuthenticationSasl}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MskServerlessClusterClientAuthenticationSasl {
        private final com.hashicorp.cdktf.providers.aws.msk_serverless_cluster.MskServerlessClusterClientAuthenticationSaslIam iam;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.iam = software.amazon.jsii.Kernel.get(this, "iam", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.msk_serverless_cluster.MskServerlessClusterClientAuthenticationSaslIam.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.iam = java.util.Objects.requireNonNull(builder.iam, "iam is required");
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.msk_serverless_cluster.MskServerlessClusterClientAuthenticationSaslIam getIam() {
            return this.iam;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("iam", om.valueToTree(this.getIam()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.mskServerlessCluster.MskServerlessClusterClientAuthenticationSasl"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MskServerlessClusterClientAuthenticationSasl.Jsii$Proxy that = (MskServerlessClusterClientAuthenticationSasl.Jsii$Proxy) o;

            return this.iam.equals(that.iam);
        }

        @Override
        public final int hashCode() {
            int result = this.iam.hashCode();
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/msk_serverless_cluster/MskServerlessClusterClientAuthenticationSasl.java <==
package com.hashicorp.cdktf.providers.aws.msk_serverless_cluster;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:10.812Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.mskServerlessCluster.MskServerlessClusterClientAuthenticationSasl")
@software.amazon.jsii.Jsii.Proxy(MskServerlessClusterClientAuthenticationSasl.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MskServerlessClusterClientAuthenticationSasl extends software.amazon.jsii.JsiiSerializable {

    /**
     * iam block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/msk_serverless_cluster#iam MskServerlessCluster#iam}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull com.hashicorp.cdktf.providers.aws.msk_serverless_cluster.MskServerlessClusterClientAuthenticationSaslIam getIam();

    /**
     * @return a {@link Builder} of {@link MskServerlessClusterClientAuthenticationSasl}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MskServerlessClusterClientAuthenticationSasl}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MskServerlessClusterClientAuthenticationSasl> {
        com.hashicorp.cdktf.providers.aws.msk_serverless_cluster.MskServerlessClusterClientAuthenticationSaslIam iam;

        /**
         * Sets the value of {@link MskServerlessClusterClientAuthenticationSasl#getIam}
         * @param iam iam block. This parameter is required.
         *            Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/msk_serverless_cluster#iam MskServerlessCluster#iam}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder iam(com.hashicorp.cdktf.providers.aws.msk_serverless_cluster.MskServerlessClusterClientAuthenticationSaslIam iam) {
            this.iam = iam;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MskServerlessClusterClientAuthenticationSasl}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MskServerlessClusterClientAuthenticationSasl build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MskServerlessClusterClientAuthenticationSasl}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MskServerlessClusterClientAuthenticationSasl {
        private final com.hashicorp.cdktf.providers.aws.msk_serverless_cluster.MskServerlessClusterClientAuthenticationSaslIam iam;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.iam = software.amazon.jsii.Kernel.get(this, "iam", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.msk_serverless_cluster.MskServerlessClusterClientAuthenticationSaslIam.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.iam = java.util.Objects.requireNonNull(builder.iam, "iam is required");
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.msk_serverless_cluster.MskServerlessClusterClientAuthenticationSaslIam getIam() {
            return this.iam;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("iam", om.valueToTree(this.getIam()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.mskServerlessCluster.MskServerlessClusterClientAuthenticationSasl"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MskServerlessClusterClientAuthenticationSasl.Jsii$Proxy that = (MskServerlessClusterClientAuthenticationSasl.Jsii$Proxy) o;

            return this.iam.equals(that.iam);
        }

        @Override
        public final int hashCode() {
            int result = this.iam.hashCode();
            return result;
        }
    }
}
